@@ -6,7 +6,7 @@ tv.mono <- function(refl, write=FALSE, nr.member = 1, tv_home, ...)
  AG <- AG[AG == nr.member]
  AG <- as.integer(names(AG))
  
- mono <- data.frame(AGG_NR = AG, AGG_NAME = tax$AGG_NAME[match(AG,tax$AGG)], AGG_RANG = taxa$RANG[match(AG,taxa$SPECIES_NR)], MEMBER_NR=as.integer(taxa$SPECIES_NR[match(AG,taxa$AGG)]), 
+ mono <- data.frame(AGG_NR = AG, AGG_NAME = taxa$AGG_NAME[match(AG, taxa$AGG)], AGG_RANG = taxa$RANG[match(AG,taxa$SPECIES_NR)], MEMBER_NR=as.integer(taxa$SPECIES_NR[match(AG,taxa$AGG)]), 
 MEMB_NAME=taxa$ABBREVIAT[match(AG,taxa$AGG)], MEMB_RANG=taxa$RANG[match(AG,taxa$AGG)])
 #for(i in 1:nrow(mono)) {
 # mono$MEMBER_NR[i] <- taxa[taxa$AGG == AG[i],1]
@@ -17,3 +17,5 @@ MEMB_NAME=taxa$ABBREVIAT[match(AG,taxa$AGG)], MEMB_RANG=taxa$RANG[match(AG,taxa$
 if(write) write.dbf(mono, paste(tv_home,'species',refl,'monotypic-D.dbf',sep='/')) else mono
 }
 # head(mono)
+
+
